@@ -13,7 +13,9 @@ from datetime import datetime
 from dateutil.relativedelta import relativedelta
 
 TZ = timezone('Europe/Madrid')
-
+PRIORITY_VERYHIGH = 1
+PRIORITY_HIGH = 2
+PRIORITY_NORMAL = 3
 
 def assertXMLEqual(got, want):
     checker = LXMLOutputChecker()
